/**
 * Browser matching rules.
 *
 * @type {Array}
 */

const BROWSER_RULES = [
    ['edge', /Edge\/([0-9\._]+)/],
    ['chrome', /(?!Chrom.*OPR)Chrom(?:e|ium)\/([0-9\.]+)(:?\s|$)/],
    ['firefox', /Firefox\/([0-9\.]+)(?:\s|$)/],
    ['opera', /Opera\/([0-9\.]+)(?:\s|$)/],
    ['opera', /OPR\/([0-9\.]+)(:?\s|$)$/],
    ['ie', /Trident\/7\.0.*rv\:([0-9\.]+)\).*Gecko$/],
    ['ie', /MSIE\s([0-9\.]+);.*Trident\/[4-7].0/],
    ['ie', /MSIE\s(7\.0)/],
    ['android', /Android\s([0-9\.]+)/],
    ['safari', /Version\/([0-9\._]+).*Safari/]
];

/**
 * Operating system matching rules.
 *
 * @type {Array}
 */

const OS_RULES = [
    ['macos', /mac os x/i],
    ['ios', /os ([\.\_\d]+) like mac os/i],
    ['android', /android/i],
    ['firefoxos', /mozilla\/[a-z\.\_\d]+ \((?:mobile)|(?:tablet)/i],
    ['windows', /windows\s*(?:nt)?\s*([\.\_\d]+)/i]
];

/**
 * Define variables to store the result.
 */

let BROWSER;
let OS;

/**
 * Run the matchers when in browser.
 */
const userAgent = window && window.navigator && window.navigator.userAgent;

for (let i = 0; i < BROWSER_RULES.length; i++) {
    const [name, regexp] = BROWSER_RULES[i];
    if (regexp.test(userAgent)) {
        BROWSER = name;
        break;
    }
}

for (let i = 0; i < OS_RULES.length; i++) {
    const [name, regexp] = OS_RULES[i];
    if (regexp.test(userAgent)) {
        OS = name;
        break;
    }
}

/**
 * Export.
 *
 * @type {Object}
 */
export const IS_CHROME = BROWSER === 'chrome';
export const IS_FIREFOX = BROWSER === 'firefox';
export const IS_SAFARI = BROWSER === 'safari';
export const IS_IE = BROWSER === 'ie';              // ie <= 11
export const IS_EDGE = BROWSER === 'edge';
export const IS_OLD_OPERA = (function isPresto() {
    var opera = window && window.opera;
    return typeof opera === 'object'
        && typeof opera.version === 'function'
        && parseInt(opera.version(), 10) <= 12;
})();

export const IS_MAC = OS === 'macos';
export const IS_WINDOWS = OS === 'windows';

export const SPACEBAR_CODE = 32;
export const SPACEBAR_CHAR = String.fromCharCode(SPACEBAR_CODE);

export const SUPPORT_COMPOSITION_EVENT = window && ('CompositionEvent' in window);
export const SUPPORT_TEXTINPUT_EVENT = window && window.document
    && ('TextEvent' in window)
    && !window.document.documentMode
    && !IS_OLD_OPERA;
// 截止17年11月14日，最新版safari已经支持了LEVEL2版本的beforeInput事件
// 将来其他浏览器支持之后可以放开
export const SUPPORT_BEFOREINPUT_EVENT = IS_SAFARI && window && window.document
    && 'onbeforeinput' in window.document.documentElement;
// Firefox 旧版不支持 onselectionchange 事件
export const SUPPORT_SELECTIONCHANGE_EVENT = window && window.document
    && 'onselectionchange' in window.document;

// 是否使用fallback的compositionend数据
// IE下的componsitionend事件有bug，标点符号的输入值不能通过event.data获取
export const USE_FALLBACK_COMPOSITION_DATA = IS_IE && SUPPORT_COMPOSITION_EVENT;

// console.log('SUPPORT_COMPOSITION_EVENT:' + SUPPORT_COMPOSITION_EVENT);
// console.log('SUPPORT_TEXTINPUT_EVENT:' + SUPPORT_TEXTINPUT_EVENT);
// console.log('SUPPORT_BEFOREINPUT_EVENT:' + SUPPORT_BEFOREINPUT_EVENT);
// console.log('SUPPORT_SELECTIONCHANGE_EVENT:' + SUPPORT_SELECTIONCHANGE_EVENT);
// console.log('USE_FALLBACK_COMPOSITION_DATA:' + USE_FALLBACK_COMPOSITION_DATA);
