import {SUPPORT_BEFOREINPUT_EVENT} from '../constants/env';

export const name = 'beforeinput';

export function callback(e, domState) {
    // console.log('beforeinput', e, e.inputType, e.data,
    //     e.dataTransfer && e.dataTransfer.getData('text/plain'),
    //     e.dataTransfer && e.dataTransfer.getData('text/html'));
    e.preventDefault();
    // Level 1 spec: https://www.w3.org/TR/input-events/
    // Level 2 spec: https://w3c.github.io/input-events/#interface-InputEvent
    // Webkit blog: https://webkit.org/blog/7358/enhanced-editing-with-input-events/

    const inputType = e.inputType;
    if (inputType === 'insertFromComposition' || inputType === 'insertText') {
        domState.onInsertText(e.data);
        return;
    }

    if (inputType === 'insertReplacementText') {
        const ranges = e.getTargetRanges();
        if (ranges && ranges[0]) {
            domState.applyRange(ranges[0]);
        }
        // 空格在mac的默认输入法下，当先输入中文然后在连续按两次空格会变成句号
        // 但是在beforeinput事件中，如果preventDefault了，则两次连续的空格会变成输入一个空格并选中它
        // 这个case会触发 ‘insertReplacementText’ 类型
        domState.onInsertText(e.dataTransfer.getData('text/plain'));
        return;
    }
}

export const NOT_BIND = !SUPPORT_BEFOREINPUT_EVENT;
