import {
    SUPPORT_BEFOREINPUT_EVENT, SUPPORT_TEXTINPUT_EVENT,
    SUPPORT_COMPOSITION_EVENT, USE_FALLBACK_COMPOSITION_DATA
} from '../constants/env';

export const name = 'compositionend';

/**
 * Google Input Tools provides composition data via a CustomEvent,
 * with the `data` property populated in the `detail` object. If this
 * is available on the event object, use it. If not, this is a plain
 * composition event and we have nothing special to extract.
 *
 * @param {Event} e event object
 * @return {string} data
 */
function getDataFromCustomEvent(e) {
    const detail = e.detail;
    if (typeof detail === 'object' && 'data' in detail) {
        return detail.data;
    }
    return null;
}

export function callback(e, domState) {
    // console.log('compositionend', e.data);
    domState.inComposing = false;

    if (SUPPORT_BEFOREINPUT_EVENT || SUPPORT_TEXTINPUT_EVENT) {
        // 会在beforeinput事件或者textInput事件中触发插入
        return;
    }

    if (USE_FALLBACK_COMPOSITION_DATA) {
        const imeText = domState.fallbackCompositionState.end();
        // console.log('fallbackCompositionEnd:' + imeText);
        domState.onInsertText(imeText);
        return;
    }

    const data = e.data || getDataFromCustomEvent(e);
    domState.onInsertText(data);
}

export const NOT_BIND = !SUPPORT_COMPOSITION_EVENT;
