export const name = 'keydown';
import {SUPPORT_SELECTIONCHANGE_EVENT, IS_MAC, USE_FALLBACK_COMPOSITION_DATA} from '../constants/env';
import isKeyCommand from '../../util/isKeyCommand';

function isMod(e) {
    return IS_MAC ? e.metaKey : e.ctrlKey;
}
function isUndo(e) {
    return isMod(e) && e.which === 90;
}
function isRedo(e) {
    return isMod(e)
        && (IS_MAC
            ? (e.which === 90 && e.shiftKey)
            : e.which === 89);
}

export function callback(e, domState) {
    // console.log('keydown', e.which, String.fromCharCode(e.which));
    switch (e.which) {
        case 8:
            e.preventDefault();
            domState.onBackspace();
            break;
        case 46:
            e.preventDefault();
            domState.onDel();
            break;
        case 13:
            e.preventDefault();
            domState.onEnter();
            break;
        case 37:
            if (e.shiftKey) {
                if (!SUPPORT_SELECTIONCHANGE_EVENT) {
                    domState.onSelectionChange();
                }
                return;
            }
            e.preventDefault();
            domState.onBackward(e);
            break;
        case 39:
            if (e.shiftKey) {
                if (!SUPPORT_SELECTIONCHANGE_EVENT) {
                    domState.onSelectionChange();
                }
                return;
            }
            e.preventDefault();
            domState.onForward(e);
            break;
        case 229:
            if (USE_FALLBACK_COMPOSITION_DATA && !domState.inComposing) {
                domState.inComposing = true;
                domState.fallbackCompositionState.start(e.target);
            }
            break;
        default:
            if (isRedo(e)) {
                e.preventDefault();
                domState.onRedo();
            }
            else if (isUndo(e)) {
                e.preventDefault();
                domState.onUndo();
            }
            else if (!SUPPORT_SELECTIONCHANGE_EVENT && isKeyCommand(e)) {
                setTimeout(() => domState.onSelectionChange(), 0);
            }
            break;
    }
}
