import {
    SUPPORT_TEXTINPUT_EVENT, SUPPORT_BEFOREINPUT_EVENT,
    SPACEBAR_CODE, SPACEBAR_CHAR
} from '../constants/env';
import isKeyCommand from '../../util/isKeyCommand';

export const name = 'keypress';

export function callback(e, domState) {
    // console.log('keypress', String.fromCharCode(e.which));
    const which = e.which;
    if (SUPPORT_BEFOREINPUT_EVENT) {
        return;
    }

    if (SUPPORT_TEXTINPUT_EVENT) {
        if (which !== SPACEBAR_CODE) {
            return;
        }

        e.preventDefault(); // 避免旧版safari里面按空格健会向下滚动的bug
        domState.hasSpaceKeypress = true;
        domState.onInsertText(SPACEBAR_CHAR);
        return;
    }

    /**
     * As of v27, Firefox may fire keypress events even when no character
     * will be inserted. A few possibilities:
     *
     * - `which` is `0`. Arrow keys, Esc key, etc.
     *
     * - `which` is the pressed key code, but no char is available.
     *   Ex: 'AltGr + d` in Polish. There is no modified character for
     *   this key combination and no character is inserted into the
     *   document, but FF fires the keypress for char code `100` anyway.
     *   No `input` event will occur.
     *
     * - `which` is the pressed key code, but a command combination is
     *   being used. Ex: `Cmd+C`. No character is inserted, and no
     *   `input` event will occur.
     */
    if (!isKeyCommand(e)) {
        // 在keypress中阻止默认行为，就不会触发textInput
        e.preventDefault();
        // IE fires the `keypress` event when a user types an emoji via
        // Touch keyboard of Windows.  In such a case, the `char` property
        // holds an emoji character like `\uD83D\uDE0A`.  Because its length
        // is 2, the property `which` does not represent an emoji correctly.
        // In such a case, we directly return the `char` property instead of
        // using `which`.
        if (e.char && e.char.length > 1) {
            domState.onInsertText(e.char);
        }
        else if (which) {
            domState.onInsertText(String.fromCharCode(which));
        }
    }
}
