const MAX_UNDOSTACK_LENGTH = 20;

export default function history(editorStateProto) {
    editorStateProto.snapshotSelection = function () {
        const {selection} = this;
        return Object.keys(selection).reduce((result, key) => {
            result[key] = selection[key];
            return result;
        }, {});
    };

    editorStateProto.applySelection = function (nextSelection) {
        Object.keys(nextSelection).forEach((key) => {
            this.selection[key] = nextSelection[key];
        });
        this.selectionApplyed = false;
        this.updateSelectedNoneTextNode();
    };

    editorStateProto.snapshot = function () {
        const {lines} = this;
        const selection = this.snapshotSelection();
        const newLines = lines.map((line) => line.map((item) => {
            if (item.kind !== 'text') {
                return item;
            }

            const newItem = {...item};
            // firefox下存在key不变dom不刷新的情况，故强制更新key值
            // 替换选中对象中的key，确保可用
            this.replaceNodeKey(newItem, selection);
            return newItem;
        }));
        return {
            selection,
            lines: newLines
        };
    };

    editorStateProto.stopIgnoreNextSave = function () {
        this.notIgnoreNextSave = true;
    };

    editorStateProto.save = function (operation) {
        if (!this.notIgnoreNextSave) {
            const lastState = this.undoStack[this.undoStack.length - 1];
            const prevOperation = lastState ? lastState.operation : null;
            this.redoStack.length = 0;
            if (operation === prevOperation) {
                return;
            }
        }
        else {
            this.notIgnoreNextSave = false;
        }

        const snapshot = this.snapshot();
        snapshot.operation = operation;
        this.undoStack.push(snapshot);
        if (this.undoStack.length > MAX_UNDOSTACK_LENGTH) {
            this.undoStack.shift();
        }
    };

    editorStateProto.applyState = function (nextState) {
        const {selection, lines} = nextState;
        const currentLines = this.lines;
        currentLines.length = 0;
        currentLines.push.apply(currentLines, lines);
        this.applySelection(selection);
    };

    editorStateProto.undo = function () {
        const nextState = this.undoStack.pop();
        if (!nextState) {
            return;
        }
        const now = this.snapshot();
        this.redoStack.push(now);
        this.applyState(nextState);
    };

    editorStateProto.redo = function () {
        const nextState = this.redoStack.pop();
        if (!nextState) {
            return;
        }
        const now = this.snapshot();
        this.undoStack.push(now);
        this.applyState(nextState);
    };
}
