import {IS_IE} from './constants/env';

const OBSERVER_OPTIONS = {
    childList: false,
    characterData: true,
    attributes: false,
    subtree: true,
    characterDataOldValue: true
};

export default class Observer {
    constructor(domState) {
        this.domState = domState;
        this.dirty = null;
        if (window.MutationObserver && !IS_IE) {
        // if (false) {
            this.observer = new window.MutationObserver(this.callbacks.bind(this));
        }
        else {
            this.onCharData = (e) => {
                this.callback({
                    target: e.target,
                    type: 'characterData',
                    oldValue: e.prevValue
                });
            };
        }
    }
    bind() {
        if (this.observer) {
            this.observer.observe(this.domState.el, OBSERVER_OPTIONS);
        }
        else {
            this.domState.el.addEventListener('DOMCharacterDataModified', this.onCharData, false);
        }
    }
    flush() {
        if (this.observer) {
            this.observer.takeRecords();
        }
    }
    unbind() {
        if (this.observer) {
            this.flush();
            this.observer.disconnect();
        }
        else {
            this.domState.el.removeEventListener('DOMCharacterDataModified', this.onCharData);
        }
    }
    callbacks(mutations) {
        for (let i = 0; i < mutations.length; i++) {
            this.callback(mutations[i]);
        }
    }
    callback(mutation) {
        if (mutation.type !== 'characterData'
            || (this.domState.state.isCollapsed()
                && this.domState.state.findStartNode().node.kind === 'text')) {
            return;
        }

        if (this.domState.inComposing && !this.dirty) {
            this.dirty = {
                target: mutation.target,
                oldValue: mutation.oldValue
            };
        }
    }

    clean() {
        setTimeout(() => {
            if (!this.dirty) {
                return;
            }
            this.unbind();
            this.dirty.target.nodeValue = this.dirty.oldValue;
            this.dirty = null;
            // console.log(this.domState.state.selection.startKey, this.domState.state.selection.startOffset);
            this.domState.forceRestoreSelection();
            this.bind();
        });
    }
}
