/**
 * Find the closest ancestor of a DOM `element` that matches a given selector.
 *
 * COMPAT: In IE11, the `Node.closest` method doesn't exist natively, so we
 * have to polyfill it. (2017/09/06)
 *
 * https://developer.mozilla.org/en-US/docs/Web/API/Element/closest#Polyfill
 *
 * @param {Element} node
 * @param {String} selector
 * @return {Element}
 */

function closest(node, selector, root) {
    if (typeof node.closest === 'function') {
        return node.closest(selector);
    }

    const matches = (node.document || node.ownerDocument).querySelectorAll(selector);
    let parentNode = node;
    do {
        for (let i = 0; i < matches.length; i++) {
            if (matches.item(i) === parentNode) {
                return parentNode;
            }
        }
        parentNode = parentNode.parentNode;
    }
    while (root.contains(parentNode));
}

/**
 * Export.
 *
 * @type {Function}
 */

export default closest;
