/**
 * v-full directive
 *
 * Usage:
 *  v-full:someRef="watchedProperty"
 */

let requestFnName;
let exitFnName;
let fullEleName;
let fsChangeEvtName;
if (document.exitFullscreen) {
    requestFnName = 'requestFullscreen';
    exitFnName = 'exitFullscreen';
    fullEleName = 'fullscreenElement';
    fsChangeEvtName = 'onfullscreenchange';
}
else if (document.webkitExitFullscreen) {
    requestFnName = 'webkitRequestFullscreen';
    exitFnName = 'webkitExitFullscreen';
    fullEleName = 'webkitFullscreenElement';
    fsChangeEvtName = 'onwebkitfullscreenchange';
}
else if (document.mozCancelFullScreen) {
    requestFnName = 'mozRequestFullScreen';
    exitFnName = 'mozCancelFullScreen';
    fullEleName = 'mozFullScreenElement';
    fsChangeEvtName = 'onmozfullscreenchange';
}
else if (document.msExitFullscreen) {
    requestFnName = 'msRequestFullscreen';
    exitFnName = 'msExitFullscreen';
    fullEleName = 'msFullscreenElement';
    fsChangeEvtName = 'onmsfullscreenchange';
}
else {
    // browser do not support full screen;
    requestFnName = '';
}

const TOGGLE_HOOK_PROPNAME = 'VHTML_TOGGLE_HOOKS_PROP_NAME';

import message from 'vhtml-ui/packages/message';

export default {
    name: 'full',
    inserted(el, binding, vnode) {
        const context = vnode.context;
        const targetRef = binding.arg;
        const target = context.$refs[targetRef];
        const watchPropName = binding.expression;

        if (!targetRef || !target) {
            return;
        }

        if (requestFnName === '') {
            el.addEventListener('click', () => {
                message.normal('当前浏览器不支持全屏模式！');
            });
            return;
        }

        let toggleCallback = function () {
            if (!document[fullEleName]) {
                target[requestFnName]();
            }
            else {
                document[exitFnName]();
            }
        };

        el.addEventListener('click', toggleCallback);

        Object.defineProperty(el, TOGGLE_HOOK_PROPNAME, {
            value: toggleCallback,
            configurable: true,
            enumerable: false
        });

        const fullchangeHandler = function () {
            context[watchPropName] = !!document[fullEleName];
        };
        document[fsChangeEvtName] = fullchangeHandler;

    },

    unbind(el) {
        const callback = el[TOGGLE_HOOK_PROPNAME];
        el.removeEventListener('click', callback);
        document[fsChangeEvtName] = null;
    }
};
