/**
 * v-hold directive
 *
 * Usage:
 * add v-hold.delay1000.quad="action" to target node
 */
import util from './accelerateUtil';
export default {
    name: 'hold',
    bind(el, binding, vnode) {
        let action = binding.value;
        let modifiers = binding.modifiers;
        let delay = 1000;
        let acceFunc = util.linear;

        if (modifiers) {
            for (let key in modifiers) {
                if (util[key]) {
                    acceFunc = util[key];
                }
                else if (/^delay\d+$/.test(key)) {
                    delay = parseInt(key.replace('delay', ''), 10);
                }
            }
        }

        (function (iDelay) {
            let timer;
            let initial = iDelay;

            function accelerate() {
                timer = setTimeout(() => {
                    accelerate(action);
                    action();
                }, iDelay);
                iDelay = acceFunc(iDelay);
            }

            el.addEventListener('mousedown', () => {
                accelerate();
            });

            el.addEventListener('mouseup', () => {
                clearTimeout(timer);
                iDelay = initial;
            });
        })(delay);
    }
};
