import Vue from 'vue';
import Message from './message.vue';

let MessageConstructor = Vue.extend(Message);
let instance;

let MESSAGE_KIND = ['normal', 'success', 'error', 'warning'];
let defaultDuration = 2000;

/**
 * Message处理函数
 * @param {string} content                    消息内容
 * @param {string} kind                       消息类型：normal、success、error、warning
 * @param {function} onClose                  消息窗关闭时的回调函数
 * @param {number} [duration=defaultDuration] 消息显示时长
 * @return {instance}                         返回当前消息的实例
 */
var message = function (content, kind, onClose, duration = defaultDuration) {
    if (!onClose) {
        onClose = function () {};
    }

    instance = new MessageConstructor({
        data: {
            content: content,
            kind: kind,
            onClose: onClose,
            duration: duration
        }
    });

    instance.vm = instance.$mount();
    document.body.appendChild(instance.vm.$el);
    instance.vm.visible = true;

    return instance.vm;
};

// 在message上为每种消息类型注册各自的方法
MESSAGE_KIND.forEach(kind => {
    message[kind] = (content, onClose, duration) => {
        if (!onClose) {
            onClose = function () {};
        }
        return message(content, kind, onClose, duration);
    };
});

export default message;
