const callbackMaps = new WeakMap();
let interval;
const IE = /msie (\d+\.\d+)/i.test(navigator.userAgent)
    ? ((document.documentMode + '') || RegExp['\x241']) : '';   // eslint-disable-line

export function bindEvent(element, callback) {
    let config = callbackMaps.get(element);
    if (!config) {
        config = {};
        callbackMaps.set(element, config);
    }

    config.callbacks = config.callbacks || [];
    config.callbacks.push(callback);
    enableEvent(element);
}

export function unbindEvent(element, callback) {
    let config = callbackMaps.get(element);
    if (!config || !config.callbacks.length) {
        return;
    }

    const i = config.callbacks.indexOf(callback);
    if (i < 0) {
        return;
    }

    config.callbacks.splice(i, 1);
    if (!config.callbacks.length) {
        disableEvent(element);
    }
}

export function enableEvent(element) {
    let config = callbackMaps.get(element);
    if (!config) {
        config = {};
        callbackMaps.set(element, config);
    }

    if (config.hasEvent) {
        return;
    }

    config.hasEvent = true;
    config.func = function () {
        if (!config.callbacks || !config.callbacks.length) {
            return;
        }

        config.callbacks.forEach((callback) => {
            callback.apply(this, arguments);
        });
    };
    element.addEventListener('scroll', config.func, false);
    element.addEventListener('resize', config.func, false);
    element.addEventListener('transitionend', config.func, false);
    // 每秒强制刷新一次
    if ((IE && IE <= 9) && typeof element.setInterval === 'function') {
        // is window
        interval = element.setInterval(config.func, 1000);
    }
}

export function disableEvent(element) {
    let config = callbackMaps.get(element);
    if (!config || !config.func || !config.hasEvent) {
        return;
    }

    element.removeEventListener('scroll', config.func);
    element.removeEventListener('resize', config.func);
    element.removeEventListener('transitionend', config.func);
    if ((IE && IE <= 9)
        && (typeof element.setInterval === 'function')
        && (interval != null)) {
        element.clearInterval(interval);
    }
    config.hasEvent = false;
    config.func = null;
}
