/**
 * v-spinner directive
 *
 * Usage:
 *  v-spinner="true"
 *  v-spinner="false"
 */
import {addClass, removeClass, hasClass} from 'vhtml-ui/src/utils/dom';

const SPINNING_CLASS = 'v-spinner__container';
const SPINNING_INNER_CLASS = 'v-spinner--inner';
const SPINNING_OPEN_CLASS = 'v-spinner--open';

const findSpinner = function (el, binding) {
    const query = binding.arg ? `#${binding.arg}` : '.v-spinner';
    return el.querySelector(query);
};

const spinning = function (spinner, visible) {
    const oldVisible = hasClass(spinner, SPINNING_OPEN_CLASS);
    if (oldVisible === visible) {
        return;
    }

    if (visible) {
        addClass(spinner, SPINNING_OPEN_CLASS);
    }
    else {
        removeClass(spinner, SPINNING_OPEN_CLASS);
    }
};

export default {
    bind(el, binding, vnode) {
        addClass(el, SPINNING_CLASS);
        const spinner = findSpinner(el, binding);
        if (!spinner) {
            return;
        }
        addClass(spinner, SPINNING_INNER_CLASS);
        spinning(spinner, binding.value);
    },

    update(el, binding, vnode) {
        // 避免update之后class被覆盖掉，故重新再添加一次
        addClass(el, SPINNING_CLASS);
        const spinner = findSpinner(el, binding);
        if (!spinner) {
            return;
        }
        spinning(spinner, binding.value);
    },

    unbind(el, binding) {
        removeClass(el, SPINNING_CLASS);
        const spinner = findSpinner(el, binding);
        if (!spinner) {
            return;
        }
        removeClass(spinner, SPINNING_INNER_CLASS);
        spinning(spinner, false);
    }
};
