import {addClass, removeClass, hasClass} from 'vhtml-ui/src/utils/dom';

const STICKY_HOOK_PROPNAME = 'VHTML_STICKY_HOOKS_PROP_NAME';
const STICKY_CLASS = 'is-sticky';

export default {
    /**
     * bind trigger event
     * @param {Element} triggerElement trigger element
     */
    bind(triggerElement) {
        // // cache initial rect for reset
        // let originRect = triggerElement.getBoundingClientRect();
        let resizeTimer;
        let placeholder;
        let placeholderId = '';

        const stickyCallback = () => {
            let fromTop = hasClass(triggerElement, STICKY_CLASS)
                    ? placeholder.getBoundingClientRect().top
                    : triggerElement.getBoundingClientRect().top;

            if (fromTop <= 1) {
                if (!hasClass(triggerElement, STICKY_CLASS)) {
                    let originRect = triggerElement.getBoundingClientRect();

                    // create placehoder node as the same style/class with current node.
                    placeholder = document.createElement(triggerElement.tagName);
                    placeholderId = '__sticky_placeholder' + Date.now();
                    placeholder.id = placeholderId;
                    placeholder.setAttribute('class', triggerElement.getAttribute('class'));
                    placeholder.setAttribute('style', triggerElement.getAttribute('style'));
                    placeholder.style.height = originRect.height + 'px';
                    placeholder.style.visibility = 'hidden';

                    addClass(triggerElement, STICKY_CLASS);
                    triggerElement.style.position = 'fixed';
                    triggerElement.style.top = 0;
                    triggerElement.style.width = originRect.width + 'px';
                    triggerElement.style.left = originRect.left + 'px';
                    triggerElement.style['z-index'] = 10;

                    // add placeholder node to dom
                    triggerElement.parentNode.insertBefore(placeholder, triggerElement);
                }
            }
            else {
                if (hasClass(triggerElement, STICKY_CLASS)) {
                    removeClass(triggerElement, STICKY_CLASS);
                    // http://stackoverflow.com/questions/18691655/remove-style-on-element
                    triggerElement.style.position = '';
                    triggerElement.style.top = '';
                    triggerElement.style.width = '';
                    triggerElement.style.left = '';
                    triggerElement.style['z-index'] = '';

                    // remove placeholder node
                    if (placeholder) {
                        triggerElement.parentNode.removeChild(placeholder);
                        placeholder = null;
                    }
                }
            }
        };
        const resizeCallback = () => {
            clearTimeout(resizeTimer);

            if (!hasClass(triggerElement, STICKY_CLASS)) {
                return;
            }

            resizeTimer = setTimeout(() => {
                if (hasClass(triggerElement, STICKY_CLASS)) {
                    let placeholder = document.getElementById(placeholderId);
                    let newRect = placeholder.getBoundingClientRect();

                    let nWidth = newRect.width;
                    let nLeft = newRect.left;
                    triggerElement.style.width = nWidth + 'px';
                    triggerElement.style.left = nLeft + 'px';
                }
            }, 250);
        };

        window.addEventListener('scroll', stickyCallback);

        window.addEventListener('resize', resizeCallback);

        Object.defineProperty(triggerElement, STICKY_HOOK_PROPNAME, {
            value: {
                stickyCallback,
                resizeCallback
            },
            configurable: true,
            enumerable: false
        });

        // // unbind on popper destroy
        // popper.$on('beforeDestroy', () => {
        //     this.unbind(triggerElement);
        // });
    },

    /**
     * unbind window event
     * @param {Element} triggerElement trigger element
     */
    unbind(triggerElement) {
        /**
         * @type {Object} options
         * @type {Object} options.stickyCallback stickyCallback
         * @type {Object} options.resizeCallback resizeCallback
         */
        const options = triggerElement[STICKY_HOOK_PROPNAME];
        window.removeEventListener('scorll', options.stickyCallback);
        window.removeEventListener('resize', options.resizeCallback);
    }
};
