import uuid from 'vhtml-ui/src/utils/uuid';

// 用一个不容易冲突的key和cb的名字
const VHTML_ANCIENT_OVERLAY_KEYS = 'VHTML_ANCIENT_OVERLAY_KEYS';
const VHTML_OVERLAY_CB = 'vhtmlOverlayUpdate';

export default {
    inject: {
        // 注入所有祖先overlay的key
        [VHTML_ANCIENT_OVERLAY_KEYS]: {
            default: ''
        },
        // 注入overlay变化时的回调函数，用于抛出overlay的位置信息和key值
        [VHTML_OVERLAY_CB]: {
            default: null
        }
    },

    data() {
        const key = `${uuid()}_${Date.now().toString(36)}`;
        return {
            overlayKey: key,
            overlayDisplayKey: this[VHTML_ANCIENT_OVERLAY_KEYS]
                ? `${this[VHTML_ANCIENT_OVERLAY_KEYS]}-${key}` : key
        };
    },

    provide() {
        return {
            [VHTML_ANCIENT_OVERLAY_KEYS]: this.overlayDisplayKey
        };
    },

    methods: {
        /**
         * 判断输入的dom是否在当前overlay的子overlay中
         * 判断输入的displayKey是否是当前overlay的子overlay的key
         * @param {Element|string} domOrDisplayKey dom或者overlay的displayKey
         * @return {boolean} 是否是在子overlay中
         */
        insideSubOverlay(domOrDisplayKey) {
            if (typeof domOrDisplayKey === 'string') {
                // 是字符串key
                return domOrDisplayKey.indexOf(this.overlayDisplayKey) === 0;
            }

            if (!domOrDisplayKey || typeof domOrDisplayKey.getAttribute !== 'function') {
                return false;
            }

            // 是 DOM
            let dom = domOrDisplayKey;
            let displayKey = dom.getAttribute('data-overlay-key');
            while (!displayKey && dom && dom.parentNode && dom.nodeName !== 'BODY') {
                dom = dom.parentNode;
                displayKey = dom.getAttribute('data-overlay-key');
            }
            return displayKey
                ? displayKey.indexOf(this.overlayDisplayKey) === 0
                : false;
        }
    }
};
