
/**
 * 判断两个复杂对象是否一致，不能处理循环引用问题
 * @param {Array|Object|number|strring} a 对象
 * @param {Array|Object|number|strring} b 对象
 * @return {boolean} 是否一致
 */
export function isSame(a, b) {
    if (a === b) {
        return true;
    }

    if (Array.isArray(a) && Array.isArray(b)) {
        if (a.length !== b.length) {
            return false;
        }
        return a.every((aItem, index) => {
            return isSame(aItem, b[index]);
        });
    }
    else if (typeof a === typeof b === 'object') {
        const aKeys = Object.keys(a);
        const bKeys = Object.keys(b);
        if (aKeys.length !== bKeys.length) {
            return false;
        }
        return aKeys.every((key) => {
            return isSame(a[key], b[key]);
        });
    }

    // 类型不一样
    return false;
}

/**
 * camelCaseToDash('userId') => "user-id"
 * camelCaseToDash('waitAMoment') => "wait-a-moment"
 * camelCaseToDash('TurboPascal') => "turbo-pascal"
 * @param {string} str string.
 * @return {string} dashcased string.
 */
export function dashcase(str) {
    return str.replace(/([a-zA-Z])(?=[A-Z])/g, '$1-').toLowerCase();
}
