import {offset, getScrollLeft, getWindow} from 'vhtml-ui/src/utils/dom';

/**
 * 设置全局window的垂直方向滚动
 * @eg
 *      scrollYTo(element);
 *      scrollYTo(element, 100);
 *      scrollYTo(100);
 *
 * @param {Element|number} element 元素或者滚动的位置
 * @param {number=} scrollOffset 滚动的偏差值
 */
export function scrollYTo(element, scrollOffset) {
    if (typeof element === 'number') {
        const left = getScrollLeft();
        // scrollYTo(100)
        window.scrollTo(left, element);
    }
    else {
        // scrollYTo(element, 100)
        // scrollYTo(element, 100)
        // 在页面布局复杂，出现嵌套的时候，scrollIntoView会产生bug（Chrome下发现）
        // element.scrollIntoView();
        // 这里的实现也并非完美，但能解决大多数情况
        const rect = offset(element);
        const win = (getWindow(element) || window);
        scrollOffset = scrollOffset || 0;
        const left = getScrollLeft(win);
        win.scrollTo(left, rect.top + scrollOffset);
    }
}
